@@ -5,7 +5,7 @@ package Mojolicious::Plugin::BootstrapHelpers;
 
 # ABSTRACT: Type less bootstrap
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.0202';
+our $VERSION = '0.0203';
 
 use Mojo::Base 'Mojolicious::Plugin';
 use Mojolicious::Plugin::BootstrapHelpers::Helpers;
@@ -32,6 +32,7 @@ sub register($self, $app, $args) {
     $app->helper($tp.'button' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_button);
     $app->helper($tp.'submit_button' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_submit);
     $app->helper($tp.'badge' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_badge);
+    $app->helper($tp.'context_menu' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_context_menu);
     $app->helper($tp.'dropdown' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_dropdown);
     $app->helper($tp.'buttongroup' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_buttongroup);
     $app->helper($tp.'toolbar' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_toolbar);
@@ -84,8 +85,8 @@ Mojolicious::Plugin::BootstrapHelpers - Type less bootstrap
 <p>
 <img src="https://img.shields.io/badge/perl-5.20+-blue.svg" alt="Requires Perl 5.20+" />
 <a href="https://travis-ci.org/Csson/p5-mojolicious-plugin-bootstraphelpers"><img src="https://api.travis-ci.org/Csson/p5-mojolicious-plugin-bootstraphelpers.svg?branch=master" alt="Travis status" /></a>
-<a href="http://cpants.cpanauthors.org/release/CSSON/Mojolicious-Plugin-BootstrapHelpers-0.0202"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/Mojolicious-Plugin-BootstrapHelpers/0.0202" alt="Distribution kwalitee" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Mojolicious-Plugin-BootstrapHelpers%200.0202"><img src="http://badgedepot.code301.com/badge/cpantesters/Mojolicious-Plugin-BootstrapHelpers/0.0202" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/release/CSSON/Mojolicious-Plugin-BootstrapHelpers-0.0203"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/Mojolicious-Plugin-BootstrapHelpers/0.0203" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Mojolicious-Plugin-BootstrapHelpers%200.0203"><img src="http://badgedepot.code301.com/badge/cpantesters/Mojolicious-Plugin-BootstrapHelpers/0.0203" alt="CPAN Testers result" /></a>
 <img src="https://img.shields.io/badge/coverage-87.2%-orange.svg" alt="coverage 87.2%" />
 </p>
 
@@ -93,7 +94,7 @@ Mojolicious::Plugin::BootstrapHelpers - Type less bootstrap
 
 =head1 VERSION
 
-Version 0.0202, released 2016-08-16.
+Version 0.0203, released 2016-09-20.
 
 =head1 SYNOPSIS
 
@@ -387,10 +388,10 @@ L<Toolbars|http://htmlpreview.github.io/?https://github.com/Csson/p5-mojolicious
 
 =head1 HELPERS
 
-L<Bootstrap documentation|http://getbootstrap.com/components/#badges>
-
 =head2 Badges
 
+L<Bootstrap documentation|http://getbootstrap.com/components/#badges>
+
 =head3 Syntax
 
     %= badge $text, %has
@@ -790,6 +791,39 @@ A mandatory array reference of L<button groups|/"Button-groups">.
         </div>
     </div>
 
+=head2 Context menus
+
+Context menus are a slight variation on L<dropdowns|/Dropdowns>, where the button or other thing that opens the menu isn't part of the menu, such as menus that
+opens on right click. The context menu is created without the E<lt>div class="dropdown"E<gt>E<lt>/divE<gt> wrapper, so for it to show up at the right place its
+position must be set using either CSS or Javascript.
+
+=head3 Syntax
+
+    <%= context_menu %has, items  => [ |item| ] %>
+
+B<C<items>>
+
+Mandatory array reference consisting of one or many C<|item|>. Read more under L</"item">.
+
+=head3 Examples
+
+
+
+        <%= context_menu id => 'my-context-menu', items => [
+                ['Item 1', ['item1'] ],
+                ['Item 2', ['item2'] ],
+                [],
+                ['Item 3', ['item3'] ]
+             ] %>
+    </div>
+
+    <ul class="dropdown-menu" id="my-context-menu">
+        <li><a class="menuitem" href="item1" tabindex="-1">Item 1</a></li>
+        <li><a class="menuitem" href="item2" tabindex="-1">Item 2</a></li>
+        <li class="divider"></li>
+        <li><a class="menuitem" href="item3" tabindex="-1">Item 3</a></li>
+    </ul>
+
 =head2 Dropdowns
 
 =head3 Syntax
